@@ -33,7 +33,7 @@
 ##' @export
 ##'
 ##' @examples
-##' library("mgcv")
+##' suppressPackageStartupMessages(library("mgcv"))
 ##' \dontshow{
 ##' set.seed(2)
 ##' op <- options(cli.unicode = FALSE, digits = 6)
@@ -66,6 +66,9 @@
         smooth <- smooth[1L]
     }
     smooth_ids <- which_smooth(object, smooth) # which smooths match 'smooth'
+    if (identical(length(smooth_ids), 0L)) {
+        stop("Requested smooth '", smooth, "' not found", call. = FALSE)
+    }
     smooth_labels <- select_smooth(object, smooth)
 
     ## Need to handle by smooths here
