@@ -7,7 +7,6 @@ library("mgcv")
 library("ggplot2")
 library("datasets")
 library("vdiffr")
-theme_set(theme_grey())
 
 context("test-hgam-paper-models")
 
@@ -58,6 +57,7 @@ test_that("draw() can plot CO2 model 2", {
 ## We show smooths 1, 14, 3, 5, 10, 13 in the paper code
 test_that("draw() can plot CO2 model 3", {
     skip_on_cran()
+    skip_on_travis()
     CO2_mod3 <- gam(log(uptake) ~ s(log(conc), k = 5, m = 2, bs = "tp") +
                         s(log(conc), by = Plant_uo, k = 5, m = 1, bs = "tp") +
                         s(Plant_uo, bs = "re", k = 12),
@@ -116,7 +116,7 @@ test_that("draw() can plot bird_move model 2", {
 
 test_that("draw() can plot bird_move model 3", {
     skip_on_cran()
-    ## skip_on_travis()
+    skip_on_travis()
     bird_mod3 <- gam(count ~ species +
                          te(week, latitude, bs = c("cc", "tp"),
                             k = c(10, 10), m = 2) +
